"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var angular = require("angular");
var web_encryption_wrapper_1 = require("web-encryption-wrapper");
var RoleFactory_1 = require("./RoleFactory");
var AjaxFactory_1 = require("./AjaxFactory");
var RoleFactory_2 = require("./RoleFactory");
var UserFactory = (function () {
    function UserFactory($http, $rootScope, ajaxFactory, roleFactory) {
        this.$http = $http;
        this.$rootScope = $rootScope;
        this.ajaxFactory = ajaxFactory;
        this.roleFactory = roleFactory;
        this.clientSalt = '';
        this.LoggedIn = false;
        this.LoadCredentials();
        UserFactory.initialized = true;
    }
    UserFactory.prototype.Initialize = function () {
        if (!UserFactory.initialized || !this.user)
            this.LoadCredentials();
        this.updateRootScope();
    };
    UserFactory.prototype.getSelectList = function (resolve, reject) {
        this.ajaxFactory.httpServerCall('/api/user/', 'get', undefined, function (list) {
            var resultList = [];
            for (var i = 0; i < list.length; i++) {
                resultList.push(new Object({ label: list[i].first_name, value: list[i].id }));
            }
            resolve(resultList);
        }, function (error) {
            reject(error);
        });
    };
    UserFactory.prototype.getOneById = function (id, resolve, reject) {
        this.ajaxFactory.httpServerCall('/api/user/' + id, 'get', undefined, function (data) {
            resolve(data.data);
        }, function (error) {
            reject(error);
        });
    };
    UserFactory.prototype.StoreCredentials = function (user, token) {
        if (!user || !token)
            return;
        this.user = user;
        this.token = token;
        this.LoggedIn = true;
        delete user.password;
        localStorage.setItem('user', angular.toJson(user));
        localStorage.setItem('token', token);
        this.updateRootScope();
    };
    UserFactory.prototype.ClearCredentials = function () {
        this.user = undefined;
        this.token = undefined;
        this.LoggedIn = false;
        localStorage.removeItem('token');
        localStorage.removeItem('user');
        this.updateRootScope();
    };
    UserFactory.prototype.updateRootScope = function () {
        var _this = this;
        if (this.user && this.user.role)
            this.$rootScope.userRole = this.user.role;
        else
            this.$rootScope.userRole = 'Guest';
        this.$rootScope.loggedIn = this.LoggedIn;
        this.roleFactory.getRoles(function (roles) {
            if (!roles)
                return;
            var role = roles[_this.user.roleId];
            if (!role)
                return;
            _this.user['role'] = role.name;
        });
    };
    UserFactory.prototype.LoadCredentials = function () {
        var token = localStorage.getItem('token');
        var user = undefined;
        if (localStorage.getItem('user') !== undefined)
            user = angular.fromJson(localStorage.getItem('user'));
        if (!token || !user || !user.username) {
            this.LoggedIn = false;
            this.updateRootScope();
            return;
        }
        this.token = token;
        this.LoggedIn = true;
        this.setUser(user);
    };
    UserFactory.prototype.setUser = function (user) {
        this.user = user;
        this.StoreCredentials(user, this.token);
        return user;
    };
    UserFactory.prototype.ChangePassword = function (pswd, newPassword, success, failure) {
        if (failure === void 0) { failure = undefined; }
        this.ajaxFactory.httpServerCall('/api/user/ChangePassword', 'put', {
            username: this.user.username,
            old_password: pswd,
            password: newPassword
        }, function (response) {
            if (!response || !response)
                return failure('Server error.');
            if (response.error)
                return failure(response.message);
            if (response.success)
                return success();
            failure("not a success");
        }, failure);
    };
    UserFactory.prototype.HashString = function (toHash) {
        return web_encryption_wrapper_1.HashStringSync(toHash, this.clientSalt);
    };
    UserFactory.prototype.$get = function () {
        return this;
    };
    UserFactory.Factory = function () {
        return this.$inject;
    };
    return UserFactory;
}());
UserFactory.factoryName = 'UserFactory';
UserFactory.$inject = ['$http', '$rootScope', AjaxFactory_1.AjaxFactory.factoryName, RoleFactory_1.RoleFactory.factoryName];
UserFactory.initialized = false;
exports.UserFactory = UserFactory;
UserFactory.$inject.push(function (http, $rootScope, ajaxFactory, roleFactory) {
    return new UserFactory(http, $rootScope, ajaxFactory, roleFactory);
});
exports.UserFactoryModule = angular.module('user-factory-module', [AjaxFactory_1.AjaxFactoryModule.name, RoleFactory_2.RoleFactoryModule.name]);
exports.UserFactoryModule.factory(UserFactory.factoryName, UserFactory.Factory());
//# sourceMappingURL=UserFactory.js.map